@@ -48,7 +48,6 @@ GtkWindow * bjb_window_base_new(void);
 
 BjbController * bjb_window_base_get_controller ( BjbWindowBase *window ) ;
 
-PangoFontDescription *bjb_window_base_get_font(GtkWidget *window);
 
 void bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type);
 
@@ -58,12 +57,12 @@ BjbWindowViewType bjb_window_base_get_view_type (BjbWindowBase *win);
 
 BijiNoteBook * bjb_window_base_get_book(GtkWidget * win);
 
+
 void bjb_window_base_set_entry(GtkWidget *win, gchar *search_entry) ;
 
-void bjb_window_base_delete_entry(GtkWidget *win);
-
 gchar * bjb_window_base_get_entry(GtkWidget *win) ;
 
+
 gpointer bjb_window_base_get_main_view (BjbWindowBase *self);
 
 BijiNoteObj * bjb_window_base_get_note (BjbWindowBase *self);
@@ -77,4 +76,7 @@ gboolean bjb_window_base_set_show_search_bar (BjbWindowBase *self, gboolean show
 gboolean bjb_window_base_toggle_search_button (BjbWindowBase *self,
                                                gboolean active);
 
+
+void bjb_window_base_set_active (BjbWindowBase *self, gboolean active);
+
 #endif /* _BJB_WINDOW_BASE_H */
